@@ -36,6 +36,7 @@ class FeedEntry(object):
 		# optional
 		self.__atom_category    = None
 		self.__atom_contributor = None
+		self.__atom_published   = None
 		self.__atom_source      = None
 		self.__atom_rights      = None
 
@@ -95,10 +96,28 @@ class FeedEntry(object):
 
 		if self.__atom_content:
 			content = etree.SubElement(entry, 'content')
+			type = self.__atom_content.get('type')
 			if self.__atom_content.get('src'):
 				content.attrib['src'] = self.__atom_content['src']
 			elif self.__atom_content.get('content'):
-				content.text = self.__atom_content.get('content')
+				# Surround xhtml with a div tag, parse it and embed it
+				if type == 'xhtml':
+					content.append(etree.fromstring('''<div
+							xmlns="http://www.w3.org/1999/xhtml">%s</div>''' % \
+							self.__atom_content.get('content')))
+				# Emed the text in escaped form
+				elif not type or type.startswith('text') or type == 'html':
+					content.text = self.__atom_content.get('content')
+				# Parse XML and embed it
+				elif type.endswith('/xml') or type.endswith('+xml'):
+					content.append(etree.fromstring(self.__atom_content['content']))
+				# Everything else should be included base64 encoded
+				else:
+					raise ValueError('base64 encoded content is not supported at the moment.'
+							+ 'If you are interested , please file a bug report.')
+			# Add type description of the content
+			if type:
+				content.attrib['type'] = type
 
 		for l in self.__atom_link or []:
 			link = etree.SubElement(entry, 'link', href=l['href'])
@@ -139,6 +158,10 @@ class FeedEntry(object):
 				email = etree.SubElement(contrib, 'url')
 				email.text = c.get('uri')
 
+		if self.__atom_published:
+			published   = etree.SubElement(entry, 'published')
+			published.text = self.__atom_published.isoformat()
+
 		if self.__atom_rights:
 			rights = etree.SubElement(feed, 'rights')
 			rights.text = self.__atom_rights
@@ -169,7 +192,7 @@ class FeedEntry(object):
 		if self.__rss_description:
 			description = etree.SubElement(entry, 'description')
 			description.text = self.__rss_description
-		for a in self.__rss_author:
+		for a in self.__rss_author or []:
 			author = etree.SubElement(entry, 'author')
 			author.text = a
 		if self.__rss_guid:
@@ -311,7 +334,7 @@ class FeedEntry(object):
 		return self.__atom_author
 
 
-	def content(self, content=None, src=None):
+	def content(self, content=None, src=None, type=None):
 		'''Get or set the cntent of the entry which contains or links to the
 		complete content of the entry. Content must be provided for ATOM entries
 		if there is no alternate link, and should be provided if there is no
@@ -326,6 +349,8 @@ class FeedEntry(object):
 			self.__atom_content = {'src':src}
 		elif not content is None:
 			self.__atom_content = {'content':content}
+			if not type is None:
+				self.__atom_content['type'] = type
 			self.__rss_description = content
 		return self.__atom_content
 
@@ -380,7 +405,8 @@ class FeedEntry(object):
 			self.__atom_link += ensure_format( link, 
 					set(['href', 'rel', 'type', 'hreflang', 'title', 'length']),
 					set(['href']), 
-					{'rel':['alternate', 'enclosure', 'related', 'self', 'via']} )
+					{'rel':['alternate', 'enclosure', 'related', 'self', 'via']},
+					{'rel': 'alternate'} )
 			# RSS only needs one URL. We use the first link for RSS:
 			for l in self.__atom_link:
 				if l.get('rel') == 'alternate':
